/*-------------------------------------------------------------------
   Name: DynamicMA.mq4
   Copyright 2010, Xaphod, http://forexwhiz.appspot.com
   
   Description: Changes the MA when switching time frames so the MA
                is consistent with the price action
                MA value is based on a reference TF and 
	         
   Change log: 
       2010-03-31 Xaphod 
          - v1.00 Release 
-----------------------------------------------------------------*/
#property copyright "Copyright  2010, Xaphod"
#property link      "http://forexwhiz.appspot.com"

#property indicator_chart_window
#property indicator_buffers 1
#property indicator_color1 Orange
//---- input parameters
extern string   BaseTFInfo="<< Base Timeframe >>";
extern int      BaseTF=15;
extern string   MAPeriodInfo="<< MA Period. Deactivate: MA=0 >>";
extern int      MAPeriod=20;
extern string   MAShiftInfo="<< MA Shift >>";
extern int      MAShift=0;
extern string   MAModeInfo="<< SMA=0, EMA=1, SMMA=2, LWMA=3 >>";
extern int      MAMode=0;
extern string   MAPriceInfo0="<< CLOSE=0, OPEN=1, HIGH=2, LOW=3 >>";
extern string   MAPriceInfo1="<< MEDIAN=4, TYPICAL=5, WEIGHTED=6 >>";
extern int      MAPrice;
//---- buffers
double dIndBuf1[];

//  Globals
int iMADynPeriod=0;

//---- Indicator name & version
string sIndicatorName;
string sVersion = "v1.00";


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init() {
  double dBaseTF=BaseTF;
  double dMAPeriod=MAPeriod;
  //- Init indicator buffers
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,dIndBuf1);
  
  // Set MA for current period
  iMADynPeriod=NormalizeDouble( (dBaseTF/Period())*dMAPeriod,0);
  SetIndexLabel(0,"MA"+iMADynPeriod);
  
  // Set indicator name  
  sIndicatorName = "DynamicMA " + sVersion;
  IndicatorShortName(sIndicatorName);
  
  // exit
  return(0);
}


//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit() {
//----
  return(0);
}


//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start() {
  int iNewBars;
  int iCountedBars;   
  
  // Get unprocessed bars
  iCountedBars=IndicatorCounted();
  if(iCountedBars < 0) return (-1); 
  iNewBars=Bars-iCountedBars;
  
  // Display MA
  if (MAPeriod>0)
    for(int i=iNewBars; i>=0; i--) 
      dIndBuf1[i]=iMA(NULL,0,iMADynPeriod,MAShift,MAMode,MAPrice,i);
   
  // Exit
   return(0);
  }
//+------------------------------------------------------------------+


